UiElementColorBuilder class
Widget that builds itself based on a provided UiElementContainer
instance provided by SharedUiElementColorContainerInstanceProvider.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- UiElementColorBuilder
Constructors
- UiElementColorBuilder({Key? key, UiElementColorContainerInstanceProvider uiElementColorContainerInstanceProvider = const SharedUiElementColorContainerInstanceProvider(), required Widget builder(BuildContext, UiElementColorContainer), Widget errorBuilder(BuildContext, Object?)?, Widget missingDataBuilder(BuildContext)?})
-
Creates a UiElementColorBuilder that builds itself based on a provided
UiElementContainerinstance.const
Properties
- builder → Widget Function(BuildContext, UiElementColorContainer)
-
Called at build time to construct a widget tree.
final
- errorBuilder → Widget Function(BuildContext, Object?)?
-
Called when an error is encountered.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- missingDataBuilder → Widget Function(BuildContext)?
-
Called when there is currently no
UiElementContaineravailable.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uiElementColorContainerInstanceProvider → UiElementColorContainerInstanceProvider
-
The UiElementColorContainerInstanceProvider that provides the
UiElementColorContainer to be used by this UiElementColorBuilder.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< UiElementColorBuilder> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited