SharedUiElementColorContainerInstanceProvider class
A class that provides a global instance of UiElementColorContainer.
sharedInstance is initially null until maybeUpdate is called for the
first time.
- Implemented types
Constructors
-
Creates a SharedUiElementColorContainerInstanceProvider, a class that
provides a global instance of UiElementColorContainer.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instance → UiElementColorContainer?
-
The global shared instance of UiElementColorContainer.
no setteroverride
-
onInstanceUpdatedStream
→ Stream<
UiElementColorContainer> -
A stream that can be used to listen for
sharedInstancechanges.no setteroverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deregisterMediaQueryData(
MediaQueryDataRegistration registration) → void -
Deregisters a MediaQueryData object from this
SharedUiElementColorContainerInstanceProvider.
override
-
maybeUpdate(
BuildContext context) → Future< void> -
Generates a new UiElementColorContainer and updates the current
sharedInstanceif a change is detected.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerMediaQueryData(
MediaQueryData mediaQueryData) → MediaQueryDataRegistration -
Registers a MediaQueryData object to this
SharedUiElementColorContainerInstanceProvider.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited